@@ -1,4 +1,4 @@
-# $Id: Svg.pm,v 1.6 2005/08/09 12:36:13 rvosa Exp $
+# $Id: Svg.pm,v 1.7 2005/08/11 19:41:13 rvosa Exp $
 # Subversion: $Rev: 148 $
 package Bio::Phylo::Unparsers::Svg;
 use strict;
@@ -8,6 +8,9 @@ use Bio::Phylo::Trees::Node;
 use SVG;
 use base 'Bio::Phylo::Unparsers';
 
+# One line so MakeMaker sees it.
+use Bio::Phylo;  our $VERSION = $Bio::Phylo::VERSION;
+
 # The bit of voodoo is for including Subversion keywords in the main source
 # file. $Rev is the subversion revision number. The way I set it up here allows
 # 'make dist' to build a *.tar.gz without the "_rev#" in the package name, while
@@ -15,11 +18,11 @@ use base 'Bio::Phylo::Unparsers';
 # with the "_rev#".
 my $rev = '$Rev: 148 $';
 $rev =~ s/^[^\d]+(\d+)[^\d]+$/$1/;
-our $VERSION = '0.03';
 $VERSION .= '_' . $rev;
-my $VERBOSE = 1;
 use vars qw($VERSION);
 
+my $VERBOSE = 1;
+
 =head1 NAME
 
 Bio::Phylo::Unparsers::Svg - An object-oriented module for unparsing tree
@@ -316,6 +319,7 @@ sub to_string {
         }
     }
     my $tree    = $self->tree;
+    $tree->negative_to_zero;
     my $root    = $tree->get_root;
     my $maxpath =
         $self->mode eq 'CLADO'
